Module blaxel.core.client.models.jobs_network_chart
===================================================

Classes
-------

`JobsNetworkChart(received: blaxel.core.client.types.Unset | ForwardRef('JobsChartValue') = <blaxel.core.client.types.Unset object>, sent: blaxel.core.client.types.Unset | ForwardRef('JobsChartValue') = <blaxel.core.client.types.Unset object>)`
:   Jobs chart
    
    Attributes:
        received (Union[Unset, JobsChartValue]): Jobs CPU usage
        sent (Union[Unset, JobsChartValue]): Jobs CPU usage
    
    Method generated by attrs for class JobsNetworkChart.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties`
    :

    `received`
    :

    `sent`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :